NI-XNET
=======

This interface adds support for NI-XNET CAN controllers by `National Instruments`_.


.. warning::

    NI-XNET only seems to support windows platforms.


Bus
---

.. autoclass:: can.interfaces.nican.NiXNETcanBus

.. autoexception:: can.interfaces.nican.NiXNETError


.. _National Instruments: http://www.ni.com/can/
